@@ -184,6 +184,7 @@ class UnbabelApi(object):
         elif result.status_code == 400:
             raise BadRequestException(result.content)
         else:
+            logger.exception("Unknown Error")
             raise Exception("Unknown Error")
 
     def get_translations(self):
@@ -211,12 +212,17 @@ class UnbabelApi(object):
         '''
         headers={'Authorization': 'ApiKey %s:%s'%(self.username,self.api_key),'content-type': 'application/json'}
         result = requests.get("%slanguage_pair/"%self.api_url,headers=headers)
-        langs_json =  json.loads(result.content)
-        languages = [LangPair(Language(shortname=lang_json["lang_pair"]["source_language"]["shortname"],
+        try:
+            logger.debug(result.content)
+            langs_json =  json.loads(result.content)
+            languages = [LangPair(Language(shortname=lang_json["lang_pair"]["source_language"]["shortname"],
                                        name=lang_json["lang_pair"]["source_language"]["name"]),
                               Language(shortname=lang_json["lang_pair"]["target_language"]["shortname"],
                                        name=lang_json["lang_pair"]["target_language"]["name"])
                               ) for lang_json in langs_json["objects"]]
+        except:
+            logger.exception("Error decoding get language pairs")
+            languages = []
         return languages
     
     def get_tones(self):
